pub struct getNextFullDkgCeremonyCall;Expand description
Get the epoch at which a fresh DKG ceremony will be triggered
@return The epoch number. The fresh DKG ceremony runs in epoch N, and epoch N+1 uses the new DKG polynomial.
Function with signature getNextFullDkgCeremony() and selector 0x281a69ec.
function getNextFullDkgCeremony() external view returns (uint64);Trait Implementations
Sourceimpl Clone for getNextFullDkgCeremonyCall
impl Clone for getNextFullDkgCeremonyCall
Sourcefn clone(&self) -> getNextFullDkgCeremonyCall
fn clone(&self) -> getNextFullDkgCeremonyCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getNextFullDkgCeremonyCall
impl Debug for getNextFullDkgCeremonyCall
Sourceimpl<'de> Deserialize<'de> for getNextFullDkgCeremonyCall
impl<'de> Deserialize<'de> for getNextFullDkgCeremonyCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getNextFullDkgCeremonyCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getNextFullDkgCeremonyCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonAbiExt for getNextFullDkgCeremonyCall
impl JsonAbiExt for getNextFullDkgCeremonyCall
Sourceimpl Serialize for getNextFullDkgCeremonyCall
impl Serialize for getNextFullDkgCeremonyCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getNextFullDkgCeremonyCall
impl SolCall for getNextFullDkgCeremonyCall
Sourcetype Parameters<'a> = ()
type Parameters<'a> = ()
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getNextFullDkgCeremonyCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getNextFullDkgCeremonyCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype ReturnTuple<'a> = (Uint<64>,)
type ReturnTuple<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getNextFullDkgCeremonyCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getNextFullDkgCeremonyCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(
tuple: <<getNextFullDkgCeremonyCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getNextFullDkgCeremonyCall
fn new<'a>( tuple: <<getNextFullDkgCeremonyCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getNextFullDkgCeremonyCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getNextFullDkgCeremonyCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getNextFullDkgCeremonyCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getNextFullDkgCeremonyCall as SolCall>::Return,
) -> <getNextFullDkgCeremonyCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getNextFullDkgCeremonyCall as SolCall>::Return, ) -> <getNextFullDkgCeremonyCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getNextFullDkgCeremonyCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getNextFullDkgCeremonyCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getNextFullDkgCeremonyCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getNextFullDkgCeremonyCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.
impl Eq for getNextFullDkgCeremonyCall
impl StructuralPartialEq for getNextFullDkgCeremonyCall